@@ -2,7 +2,7 @@
 #
 # Author: Yipeng Sun
 # License: BSD 2-clause
-# Last Change: Tue Nov 23, 2021 at 03:51 AM +0100
+# Last Change: Wed Feb 16, 2022 at 12:53 PM -0500
 
 import numpy as np
 import matplotlib as mp
@@ -221,33 +221,21 @@ def ax_add_args_hlines(label, color, linestyles='solid'):
 ax_add_args_vlines = ax_add_args_hlines
 
 
+@decorate_ax_style
+def ax_add_args_hist2d(bins=None, cmap='YlOrRd'):
+    return {'bins': bins, 'cmap': cmap}
+
+
 ################
 # Simple plots #
 ################
 
-@decorate_output
-def plot_hexbin(x, y, gridsize, hexbin_add_args,
-                output=None, cmap='inferno', bins='log', colorbar_label=None,
-                **kwargs):
-    fig, ax, legend = plot_prepare(**kwargs)
-    hb = ax.hexbin(x, y,
-                   gridsize=gridsize, cmap=cmap, bins=bins, **hexbin_add_args)
-    cb = fig.colorbar(hb, ax=ax)
-
-    if colorbar_label:
-        cb.set_label(colorbar_label)
-
-    legend()
-    return output, fig, ax
-
-
 @decorate_output
 def plot_histo(bins, histo, histo_add_args,
                output=None, xtick_formatter=tick_formatter_short,
                **kwargs):
     fig, ax, legend = plot_prepare(xtick_formatter=xtick_formatter, **kwargs)
-    mid_bins = convert_bins_to_central_pos(bins)
-    ax.bar(mid_bins, histo, width=np.diff(bins), **histo_add_args)
+    ax.stairs(histo, bins, fill=True, **histo_add_args)
 
     legend()
     return output, fig, ax
@@ -326,6 +314,40 @@ def plot_vlines(x, y, vlines_add_args,
     return output, fig, ax
 
 
+############
+# 2D plots #
+############
+
+@decorate_output
+def plot_hexbin(x, y, hexbin_add_args,
+                output=None, colorbar_label=None,
+                **kwargs):
+    fig, ax, legend = plot_prepare(**kwargs)
+    color_mesh = ax.hexbin(x, y,  **hexbin_add_args)
+    cb = fig.colorbar(color_mesh, ax=ax)
+
+    if colorbar_label:
+        cb.set_label(colorbar_label)
+
+    legend()
+    return output, fig, ax
+
+
+@decorate_output
+def plot_hist2d(x, y, hist2d_add_args,
+                output=None, colorbar_label=None,
+                **kwargs):
+    fig, ax, legend = plot_prepare(**kwargs)
+    _, _, _, color_mesh = ax.hist2d(x, y, **hist2d_add_args)
+    cb = fig.colorbar(color_mesh, ax=ax)
+
+    if colorbar_label:
+        cb.set_label(colorbar_label)
+
+    legend()
+    return output, fig, ax
+
+
 ###################
 # Composite plots #
 ###################
